@@ -1,20 +1,32 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__version__ = '0.1'
+__version__ = '0.2'
+
+
+class RoundHouseKick(Exception):
+    pass
+
+
+def fail():
+    raise RoundHouseKick('Fix your test. Chuck Norris never fails.')
+
 
 def assert_true(value, msg=None):
-    return True
+    pass
+
 
 def assert_false(value, msg=None):
-    return True
+    pass
+
 
 def assert_raises(excClass, callableObj, *args, **kwargs):
-    return True
+    pass
+
 
 def assert_equals(first, second, msg=None):
-    return True
+    pass
+
 
 def assert_not_equals(first, second, msg=None):
-    return True
-
+    pass
